@@ -17,7 +17,7 @@
 #include "pm_matrix_tests_options.h"
 #include "pm_common_boost_type_lists.h"
 #include <gudhi/persistence_matrix_options.h>
-#include <gudhi/matrix.h>
+#include <gudhi/Matrix.h>
 
 using Gudhi::persistence_matrix::Column_types;
 using Gudhi::persistence_matrix::Matrix;
@@ -126,19 +126,19 @@ struct m_chain_options {
 template <class option>
 class matrix_non_validity {
  private:
-  static constexpr bool is_non_valide() {
+  static constexpr bool is_non_valid() {
     return (option::has_row_access || option::has_column_compression) && option::column_type == Column_types::HEAP;
   }
 
  public:
-  static constexpr bool value = is_non_valide();
+  static constexpr bool value = is_non_valid();
 };
 
 // to avoid long compilation time and high memory usage, the tests are restricted to one column type by default for
 // users. But in case real changes were made to this module, it would be better to test at least once with all column
 // types as below:
 // using col_type_list = boost::mp11::mp_list<ct_intrusive_list, ct_intrusive_set, ct_list, ct_set, ct_heap,
-//                                            ct_unordered_set, ct_vector, ct_naive_vector>;
+//                                            ct_unordered_set, ct_vector, ct_naive_vector, ct_small_vector>;
 #ifdef PM_TEST_INTR_LIST
 using col_type_list = boost::mp11::mp_list<ct_intrusive_list>;
 #else
@@ -162,6 +162,9 @@ using col_type_list = boost::mp11::mp_list<ct_unordered_set>;
 #ifdef PM_TEST_NAIVE_VECTOR
 using col_type_list = boost::mp11::mp_list<ct_naive_vector>;
 #else
+#ifdef PM_TEST_SMALL_VECTOR
+using col_type_list = boost::mp11::mp_list<ct_small_vector>;
+#else
 using col_type_list = boost::mp11::mp_list<ct_vector>;
 #endif
 #endif
@@ -170,6 +173,7 @@ using col_type_list = boost::mp11::mp_list<ct_vector>;
 #endif
 #endif
 #endif
+#endif
 
 using matrix_type_list = mp_list_q<Matrix>;
 
