@@ -18,7 +18,7 @@
  #define GUDHI_EMPTY_BASE_CLASS_OPTIMIZATION
 #endif
 
-#include <vector>
+#include <boost/core/empty_value.hpp>
 
 namespace Gudhi {
 
@@ -32,19 +32,25 @@ namespace Gudhi {
  *
  * It stores explicitly its own filtration value and its own Simplex_key.
  */
-template<class SimplexTree>
-struct GUDHI_EMPTY_BASE_CLASS_OPTIMIZATION Simplex_tree_node_explicit_storage : SimplexTree::Filtration_simplex_base,
-                                                                          SimplexTree::Key_simplex_base,
-                                                                          SimplexTree::Hooks_simplex_base {
+template <class SimplexTree>
+struct GUDHI_EMPTY_BASE_CLASS_OPTIMIZATION Simplex_tree_node_explicit_storage
+    : SimplexTree::Filtration_simplex_base,
+      SimplexTree::Key_simplex_base,
+      SimplexTree::Hooks_simplex_base,
+      boost::empty_value<typename SimplexTree::Simplex_data> {
   typedef typename SimplexTree::Siblings Siblings;
   typedef typename SimplexTree::Filtration_value Filtration_value;
   typedef typename SimplexTree::Simplex_key Simplex_key;
+  typedef typename SimplexTree::Simplex_data Simplex_data;
 
-  Simplex_tree_node_explicit_storage(Siblings * sib = nullptr,
-                                     Filtration_value filtration = 0)
-      : children_(sib) {
-    this->assign_filtration(filtration);
-  }
+  Simplex_tree_node_explicit_storage(Siblings* sib = nullptr, Filtration_value filtration = 0)
+      : SimplexTree::Filtration_simplex_base(filtration), children_(sib)
+  {}
+
+  //will fail to compile when called with SimplexTree::Options::store_key is false.
+  Simplex_tree_node_explicit_storage(Siblings* sib, Filtration_value filtration, Simplex_key key)
+      : SimplexTree::Filtration_simplex_base(filtration), SimplexTree::Key_simplex_base(key), children_(sib)
+  {}
 
   /*
    * Assign children to the node
@@ -57,6 +63,12 @@ struct GUDHI_EMPTY_BASE_CLASS_OPTIMIZATION Simplex_tree_node_explicit_storage :
   Siblings * children() {
     return children_;
   }
+  const Siblings * children() const {
+    return children_;
+  }
+
+  Simplex_data& data() { return boost::empty_value<Simplex_data>::get(); }
+  const Simplex_data& data() const { return boost::empty_value<Simplex_data>::get(); }
 
  private:
   Siblings * children_;
