@@ -15,9 +15,6 @@
 
 #include <boost/container/flat_map.hpp>
 
-#include <utility>
-#include <vector>
-
 namespace Gudhi {
 
 /** \addtogroup simplex_tree
@@ -43,6 +40,7 @@ class Simplex_tree_siblings {
   typedef typename SimplexTree::Node Node;
   typedef MapContainer Dictionary;
   typedef typename MapContainer::iterator Dictionary_it;
+  typedef typename MapContainer::const_iterator Dictionary_const_it;
 
   /* Default constructor.*/
   Simplex_tree_siblings()
@@ -74,8 +72,8 @@ class Simplex_tree_siblings {
 
   /** \brief Inserts a Node in the set of siblings nodes.
    *
-   * If already present, assigns the minimal filtration value 
-   * between input filtration_value and the value already 
+   * If already present, assigns the minimal filtration value
+   * between input filtration_value and the value already
    * present in the node.
    */
   void insert(Vertex_handle v, Filtration_value filtration_value) {
@@ -87,10 +85,16 @@ class Simplex_tree_siblings {
   Dictionary_it find(Vertex_handle v) {
     return members_.find(v);
   }
+  Dictionary_const_it find(Vertex_handle v) const {
+    return members_.find(v);
+  }
 
   Simplex_tree_siblings * oncles() {
     return oncles_;
   }
+  const Simplex_tree_siblings * oncles() const {
+    return oncles_;
+  }
 
   Vertex_handle parent() const {
     return parent_;
@@ -100,6 +104,10 @@ class Simplex_tree_siblings {
     return members_;
   }
 
+  const Dictionary & members() const {
+    return members_;
+  }
+
   size_t size() const {
     return members_.size();
   }
@@ -108,6 +116,10 @@ class Simplex_tree_siblings {
     members_.erase(iterator);
   }
 
+  Dictionary_it to_non_const_it(Dictionary_const_it it) {
+    return members_.erase(it, it);
+  }
+
   Simplex_tree_siblings * oncles_;
   Vertex_handle parent_;
   Dictionary members_;
