@@ -31,25 +31,12 @@
 
 using namespace Gudhi;
 
-struct Simplex_tree_options_stable_simplex_handles {
-  typedef linear_indexing_tag Indexing_tag;
-  typedef int Vertex_handle;
-  typedef double Filtration_value;
-  typedef std::uint32_t Simplex_key;
-  static const bool store_key = true;
-  static const bool store_filtration = true;
-  static const bool contiguous_vertices = false;
-  static const bool link_nodes_by_label = true;
-  static const bool stable_simplex_handles = true;
-};
-
 typedef boost::mpl::list<Simplex_tree<>,
                          Simplex_tree<Simplex_tree_options_fast_persistence>,
-                         Simplex_tree<Simplex_tree_options_full_featured>,
-                         Simplex_tree<Simplex_tree_options_stable_simplex_handles> > list_of_tested_variants;
+                         Simplex_tree<Simplex_tree_options_full_featured> > list_of_tested_variants;
 
 template<class typeST>
-void test_empty_simplex_tree(typeST& tst) {
+void test_empty_simplex_tree(const typeST& tst) {
   typedef typename typeST::Vertex_handle Vertex_handle;
   const Vertex_handle DEFAULT_VERTEX_VALUE = Vertex_handle(- 1);
   BOOST_CHECK(tst.null_vertex() == DEFAULT_VERTEX_VALUE);
@@ -57,7 +44,7 @@ void test_empty_simplex_tree(typeST& tst) {
   BOOST_CHECK(tst.num_simplices() == (size_t) 0);
   BOOST_CHECK(tst.is_empty());
   BOOST_CHECK(tst.num_simplices_by_dimension() == std::vector<size_t>());
-  typename typeST::Siblings* STRoot = tst.root();
+  const typename typeST::Siblings* STRoot = tst.root();
   BOOST_CHECK(STRoot != nullptr);
   BOOST_CHECK(STRoot->oncles() == nullptr);
   BOOST_CHECK(STRoot->parent() == DEFAULT_VERTEX_VALUE);
@@ -65,7 +52,7 @@ void test_empty_simplex_tree(typeST& tst) {
 }
 
 template<class typeST>
-void test_iterators_on_empty_simplex_tree(typeST& tst) {
+void test_iterators_on_empty_simplex_tree(const typeST& tst) {
   std::clog << "Iterator on vertices: " << std::endl;
   for (auto vertex : tst.complex_vertex_range()) {
     std::clog << "vertice:" << vertex << std::endl;
@@ -150,7 +137,7 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(simplex_tree_from_file, typeST, list_of_tested_var
 }
 
 template<class typeST, class typeSimplex>
-void test_simplex_tree_contains(typeST& simplexTree, typeSimplex& simplex, int pos) {
+void test_simplex_tree_contains(const typeST& simplexTree, typeSimplex& simplex, int pos) {
   auto f_simplex = simplexTree.filtration_simplex_range().begin() + pos;
 
   std::clog << "test_simplex_tree_contains - filtration=" << simplexTree.filtration(*f_simplex) << "||" << simplex.second << std::endl;
@@ -511,7 +498,7 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(NSimplexAndSubfaces_tree_insertion, typeST, list_o
     BOOST_CHECK(vertex == SimplexVector6[position]);
     position++;
   }
-  
+
   /* Inserted simplex:        */
   /*    1   6                 */
   /*    o---o                 */
@@ -606,7 +593,7 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(NSimplexAndSubfaces_tree_insertion, typeST, list_o
 }
 
 template<class typeST, class Vertex_handle>
-void test_cofaces(typeST& st, const std::vector<Vertex_handle>& expected, int dim, const std::vector<typename typeST::Simplex_handle>& res) {
+void test_cofaces(const typeST& st, const std::vector<Vertex_handle>& expected, int dim, const std::vector<typename typeST::Simplex_handle>& res) {
   std::size_t nb_res = 0;
   if (dim == 0) {
     typename typeST::Cofaces_simplex_range stars = st.star_simplex_range(st.find(expected));
@@ -831,7 +818,7 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(copy_move_on_simplex_tree, typeST, list_of_tested_
 
   std::clog << "Printing st - address = " << &st << std::endl;
 
-  // Copy constructor  
+  // Copy constructor
   typeST st_copy = st;
   std::clog << "Printing a copy of st - address = " << &st_copy << std::endl;
 
@@ -840,7 +827,7 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(copy_move_on_simplex_tree, typeST, list_of_tested_
   // Check there is a new simplex tree reference
   BOOST_CHECK(&st != &st_copy);
 
-  // Move constructor  
+  // Move constructor
   typeST st_move = std::move(st);
   std::clog << "Printing a move of st - address = " << &st_move << std::endl;
 
@@ -849,14 +836,14 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(copy_move_on_simplex_tree, typeST, list_of_tested_
   // Check there is a new simplex tree reference
   BOOST_CHECK(&st_move != &st_copy);
   BOOST_CHECK(&st_move != &st);
-  
+
   typeST st_empty;
   // Check st has been emptied by the move
   BOOST_CHECK(st == st_empty);
   BOOST_CHECK(st.dimension() == -1);
   BOOST_CHECK(st.num_simplices() == 0);
   BOOST_CHECK(st.num_vertices() == (size_t)0);
-  
+
   std::clog << "Printing st once again- address = " << &st << std::endl;
 }
 
@@ -933,7 +920,7 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(simplex_tree_insert_graph, Graph, list_of_graph_va
   st1.insert_graph(g);
   BOOST_CHECK(st1.num_simplices() == 6);
 
-  Simplex_tree<Simplex_tree_options_stable_simplex_handles> sst1;
+  Simplex_tree<Simplex_tree_options_full_featured> sst1;
   sst1.insert_graph(g);
   BOOST_CHECK(sst1.num_simplices() == 6);
 
@@ -948,7 +935,7 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(simplex_tree_insert_graph, Graph, list_of_graph_va
   st2.insert_graph(g);
   BOOST_CHECK(st2.num_simplices() == 6);
 
-  Simplex_tree<Simplex_tree_options_stable_simplex_handles> sst2;
+  Simplex_tree<Simplex_tree_options_full_featured> sst2;
   sst2.insert_graph(g);
   BOOST_CHECK(sst2.num_simplices() == 6);
 
@@ -1157,8 +1144,7 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(simplex_tree_boundaries_and_opposite_vertex_iterat
 }
 
 typedef boost::mpl::list<Simplex_tree<>,
-                         Simplex_tree<Simplex_tree_options_full_featured>,
-                         Simplex_tree<Simplex_tree_options_stable_simplex_handles> >
+                         Simplex_tree<Simplex_tree_options_full_featured> >
                            list_of_tested_variants_wo_fast_persistence;
 
 BOOST_AUTO_TEST_CASE_TEMPLATE(batch_vertices, typeST, list_of_tested_variants_wo_fast_persistence) {
